@@ -29,16 +29,16 @@ def pop_recursive(d, key, default=None):
     return default
 
 
-def _cells(nb, conditional=None):
-    """Remove cells not satisfying conditional and yield all other cells."""
+def _cells(nb, conditionals):
+    """Remove cells not satisfying any conditional in conditionals and yield all other cells."""
     if nb.nbformat < 4:
         for ws in nb.worksheets:
-            if conditional:
+            for conditional in conditionals:
                 ws.cells = list(filter(conditional, ws.cells))
             for cell in ws.cells:
                 yield cell
     else:
-        if conditional:
+        for conditional in conditionals:
             nb.cells = list(filter(conditional, nb.cells))
         for cell in nb.cells:
             yield cell
@@ -56,7 +56,7 @@ def get_size(item):
         return len(str(item))
 
 
-def determine_keep_output(cell, default):
+def determine_keep_output(cell, default, strip_init_cells=False):
     """Given a cell, determine whether output should be kept
 
     Based on whether the metadata has "init_cell": true,
@@ -64,7 +64,7 @@ def determine_keep_output(cell, default):
     if 'metadata' not in cell:
         return default
     if 'init_cell' in cell.metadata:
-        return bool(cell.metadata.init_cell)
+        return bool(cell.metadata.init_cell) and not strip_init_cells
 
     has_keep_output_metadata = 'keep_output' in cell.metadata
     keep_output_metadata = bool(cell.metadata.get('keep_output', False))
@@ -94,7 +94,8 @@ def strip_zeppelin_output(nb):
     return nb
 
 
-def strip_output(nb, keep_output, keep_count, extra_keys=[], strip_empty_cells=False, max_size=0):
+def strip_output(nb, keep_output, keep_count, extra_keys=[], drop_empty_cells=False, drop_tagged_cells=[],
+                 strip_init_cells=False, max_size=0):
     """
     Strip the outputs, execution count/prompt number and miscellaneous
     metadata from a notebook object, unless specified to keep either the outputs
@@ -108,7 +109,7 @@ def strip_output(nb, keep_output, keep_count, extra_keys=[], strip_empty_cells=F
     keys = defaultdict(list)
     for key in extra_keys:
         if '.' not in key or key.split('.')[0] not in ['cell', 'metadata']:
-            sys.stderr.write('Ignoring invalid extra key `%s`\n' % key)
+            sys.stderr.write(f'Ignoring invalid extra key `{key}`\n')
         else:
             namespace, subkey = key.split('.', maxsplit=1)
             keys[namespace].append(subkey)
@@ -116,16 +117,15 @@ def strip_output(nb, keep_output, keep_count, extra_keys=[], strip_empty_cells=F
     for field in keys['metadata']:
         pop_recursive(nb.metadata, field)
 
+    conditionals = []
     # Keep cells if they have any `source` line that contains non-whitespace
-    if strip_empty_cells:
-        def conditional(cell):
-            return any(line.strip() for line in cell.get('source', []))
-    # Keep all cells
-    else:
-        conditional = None
+    if drop_empty_cells:
+        conditionals.append(lambda c: any(line.strip() for line in c.get('source', [])))
+    for tag_to_drop in drop_tagged_cells:
+        conditionals.append(lambda c: tag_to_drop not in c.get("metadata", {}).get("tags", []))
 
-    for cell in _cells(nb, conditional):
-        keep_output_this_cell = determine_keep_output(cell, keep_output)
+    for cell in _cells(nb, conditionals):
+        keep_output_this_cell = determine_keep_output(cell, keep_output, strip_init_cells)
 
         # Remove the outputs, unless directed otherwise
         if 'outputs' in cell:
